<?php

namespace Bundler\Models;

if (!defined('ABSPATH')) exit;

class Bundle
{

    /**
     * Add a bundle to an existing offer
     * 
     * @param mixed $offer_id
     * @param mixed $title
     * @param mixed $image_url
     * @param mixed $number_of_products
     * @param mixed $sale_price
     * @param mixed $regular_price
     * @param mixed $use_custom_variations
     * @param mixed $option1_name
     * @param mixed $option1_value
     * @param mixed $option2_name
     * @param mixed $option2_value
     * @param mixed $add_messages
     * @param mixed $message
     * @param mixed $discount_rule
     * @param mixed $preselected_offer
     * @param mixed $message_effect
     * @param mixed $wmc_sale_price
     * @param mixed $wmc_regular_price
     * 
     * @return array
     */
    public static function add_bundle_to_offer(
        $offer_id,
        $title,
        $image_url,
        $number_of_products,
        $sale_price,
        $regular_price,
        $wmc_sale_price,
        $wmc_regular_price,
        $use_custom_variations,
        $option1_name,
        $option1_value,
        $option2_name,
        $option2_value,
        $add_messages,
        $message,
        $discount_rule,
        $preselected_offer,
        $message_effect,
        $show_price_per_unit
    ) {
        global $wpdb;

        $bundle_table = $wpdb->prefix . DB::$bundle_table_name;

        $wpdb->insert(
            $bundle_table,
            array(
                'offer_id'              => $offer_id,
                'bundle_title'          => $title,
                'image_url'             => $image_url,
                'number_of_products'    => $number_of_products,
                'sale_price'            => $sale_price,
                'regular_price'         => $regular_price,
                'wmc_sale_price'        => $wmc_sale_price,
                'wmc_regular_price'     => $wmc_regular_price,
                'use_custom_variations' => $use_custom_variations,
                'option1_name'          => $option1_name,
                'option1_value'         => $option1_value,
                'option2_name'          => $option2_name,
                'option2_value'         => $option2_value,
                'add_messages'          => $add_messages,
                'message'               => $message,
                'discount_rule'         => $discount_rule,
                'preselected_offer'     => $preselected_offer,
                'message_effect'        => $message_effect,
                'show_price_per_unit'   => $show_price_per_unit
            )
        );
    }

    /**
     * Get bundles for a given product id
     * 
     * @param mixed $product_id
     * 
     * @return array
     */
    public static function get_bundles_by_product_id($product_id)
    {
        global $wpdb;
        $bundle_table = $wpdb->prefix . DB::$bundle_table_name;
        $offer_table = $wpdb->prefix . DB::$offer_table_name;
        $query = $wpdb->prepare("SELECT * FROM $bundle_table INNER JOIN $offer_table 
            ON $bundle_table.offer_id = $offer_table.id
            WHERE product_id = %s", $product_id);

        return $wpdb->get_results($query);
    }

    /**
     * Get the bundles associated with an offer
     * 
     * @param mixed $offer_id
     * 
     * @return array
     */
    public static function get_bundles_by_offer_id($offer_id)
    {
        global $wpdb;
        $bundle_table = $wpdb->prefix . DB::$bundle_table_name;
        $query = $wpdb->prepare("SELECT * FROM $bundle_table WHERE offer_id = %s", $offer_id);

        return $wpdb->get_results($query);
    }

    /**
     * @param mixed $offer_id
     * 
     * @return array
     */
    public static function get_bundles_by_offer_id_sort_by_qty_desc($offer_id)
    {
        global $wpdb;

        $bundle_table = $wpdb->prefix . DB::$bundle_table_name;

        $query = $wpdb->prepare("SELECT * FROM $bundle_table
            WHERE offer_id = %s
            ORDER BY number_of_products DESC", $offer_id);

        return $wpdb->get_results($query);
    }

    /**
     * @param mixed $offer_id
     * 
     * @return void
     */
    public static function remove_bundles($offer_id)
    {
        global $wpdb;

        $bundle_table = $wpdb->prefix . DB::$bundle_table_name;
        // Remove all bundles included in the offer
        $wpdb->delete($bundle_table, array('offer_id' => $offer_id));
    }
}
