<?php

namespace Bundler\Models;

if (!defined('ABSPATH')) exit;

class Offer
{

    /**
     * Get all offers
     * 
     * @return array
     */
    public static function get_all_offers()
    {
        global $wpdb;

        $offer_table = $wpdb->prefix . DB::$offer_table_name;
        $query = "SELECT * FROM $offer_table";
        return $wpdb->get_results($query);
    }

    /**
     * Get offer by id
     * 
     * @param mixed $offer_id
     * 
     * @return array
     */
    public static function get_offer_by_id($offer_id)
    {
        global $wpdb;

        $offer_table = $wpdb->prefix . DB::$offer_table_name;
        $query = $wpdb->prepare("SELECT * FROM $offer_table where id = %s", $offer_id);
        return $wpdb->get_results($query);
    }

    /**
     * Get the offer
     * 
     * @param mixed $product_id
     * 
     * @return Bundler\Models\Offer|null
     */
    public static function get_the_offer($product_id)
    {
        global $wpdb;
        $offer_table = $wpdb->prefix . DB::$offer_table_name;
        // Get the enabled offer with the highest priority for that product
        $query = $wpdb->prepare("
            SELECT * FROM $offer_table
            where product_id = %s AND status = 'on'
            ORDER BY priority DESC
            LIMIT 1", $product_id);

        //$offer_id = $wpdb->get_var($query);
        $result = $wpdb->get_results($query);
        if ($result) {
            $offer = $result[0];
            return $offer;
        }

        return null;
    }

    /**
     * Remove offer
     * 
     * @param mixed $offer_id
     * 
     * @return void
     */
    public static function remove_offer($offer_id)
    {
        global $wpdb;

        $offer_table = $wpdb->prefix . DB::$offer_table_name;
        // Then delete the offer
        $wpdb->delete($offer_table, array('id' => $offer_id));
    }

    /**
     * New offer
     * 
     * @param mixed $product_id
     * @param mixed $title
     * @param mixed $type
     * @param mixed $status
     * @param mixed $priority
     * @param mixed $wmc
     * 
     * @return mixed
     */
    public static function new_offer($product_id, $title, $type, $status, $priority)
    {
        global $wpdb;

        $offer_table = $wpdb->prefix . DB::$offer_table_name;

        $wpdb->insert(
            $offer_table,
            array(
                'product_id' => $product_id,
                'title' => $title,
                'type' => $type,
                'status' => $status,
                'priority' => $priority,
            )
        );
        // Get the inserted offer id
        $offer_id = $wpdb->insert_id;
        // For now, the priority of the offer is its id
        $wpdb->update($offer_table, array('priority' => intval($offer_id)), array('id' => intval($offer_id)));

        return $offer_id;
    }


    /**
     * Update offer
     * 
     * @param mixed $offer_id
     * @param mixed $product_id
     * @param mixed $title
     * @param mixed $discountType
     * @param mixed $status
     * @param mixed $priority
     * @param mixed $wmc
     * 
     * @return void
     */
    public static function update_offer($offer_id, $product_id, $title, $discountType, $status, $priority)
    {
        global $wpdb;

        $offer_table = $wpdb->prefix . DB::$offer_table_name;

        $wpdb->update(
            $offer_table,
            array(
                'product_id' => $product_id,
                'title' => $title,
                'type' => $discountType,
                'status' => $status,
                'priority' => $priority
            ),
            array('id' => intval($offer_id))
        );
    }

    /**
     * enable/disable an offer
     * 
     * @param mixed $offer_id
     * @param mixed $status
     * 
     * @return void
     */
    public static function update_offer_status($offer_id, $status)
    {
        global $wpdb;

        $offer_table = $wpdb->prefix . DB::$offer_table_name;
        // Update offer's status
        $wpdb->update($offer_table, array('status' => $status), array('id' => intval($offer_id)));
    }
}
