<?php

namespace Bundler\Models;

if (!defined('ABSPATH')) exit;

class Settings
{

    /**
     * Get the current settings
     * 
     * @return array
     */
    public static function get_settings()
    {
        global $wpdb;
        $settings_table = $wpdb->prefix . DB::$settings_table_name;

        return $wpdb->get_results("SELECT * FROM $settings_table ");
    }

    /**
     * Update template settings
     * 
     * @param mixed $design_desktop
     * @param mixed $design_mobile
     * @param mixed $bundles_title
     * @param mixed $title_show
     * @param mixed $qty_selector
     * @param mixed $cart_redirect
     * @param mixed $checkout_redirect
     * @param mixed $atc_price_text
     * 
     * @return void
     */
    public static function update_template_settings($design_desktop, $design_mobile, $bundles_title, $title_show, $qty_selector, $cart_redirect, $checkout_redirect, $atc_price_text)
    {
        global $wpdb;
        $settings_table = $wpdb->prefix . DB::$settings_table_name;

        $success = $wpdb->update(
            $settings_table,
            array(
                'design'            => $design_desktop,
                'design_mobile'     => $design_mobile,
                'bundles_title'     => $bundles_title,
                'title_show'        => $title_show,
                'qty_selector'      => $qty_selector,
                'cart_redirect'     => $cart_redirect,
                'checkout_redirect' => $checkout_redirect,
                'atc_price_text'    => $atc_price_text
            ),
            array('id' => 1)
        );
    }

    /**
     * Update design settings
     * 
     * @param mixed $background_color
     * @param mixed $background_color_active
     * @param mixed $border_color
     * @param mixed $border_color_active
     * @param mixed $title_color
     * @param mixed $sale_price_color
     * @param mixed $regular_price_color
     * @param mixed $message1_color
     * @param mixed $message2_color
     * 
     * @return void
     */
    public static function update_design_settings(
        $background_color,
        $background_color_active,
        $border_color,
        $border_color_active,
        $title_color,
        $sale_price_color,
        $regular_price_color,
        $message1_color,
        $message2_color
    ) {
        global $wpdb;
        $settings_table = $wpdb->prefix . DB::$settings_table_name;

        $wpdb->update(
            $settings_table,
            array(
                'background_color'        => $background_color,
                'background_color_active' => $background_color_active,
                'border_color'            => $border_color,
                'border_color_active'     => $border_color_active,
                'title_color'             => $title_color,
                'sale_price_color'        => $sale_price_color,
                'regular_price_color'     => $regular_price_color,
                'message1_color'          => $message1_color,
                'message2_color'          => $message2_color
            ),
            array('ID' => 1)
        );
    }
}
