<?php

/**
 * Widget that will be displayed in the frontend
 *
 * @since 1.2.7
 */

namespace Bundler\Views;

use Bundler\Helpers\Cart;
use Bundler\Models\Offer;
use Bundler\Models\Settings;
use Bundler\Controllers\offer_controller;
use Bundler\Controllers\OfferController;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Widget
{

    public static function init()
    {
        add_action('woocommerce_before_add_to_cart_button', array(__CLASS__, 'display_widget'));
    }

    public static function display_widget()
    {
        global $post;

        if (get_post_type($post) === 'product') {

            $product_id = get_the_ID();
            $product = wc_get_product($product_id);

            if ($product->is_type('simple')) {

                $offer_controller = new OfferController();
                $bundles = $offer_controller->get_the_bundles($product_id);

                $cart_helper = new Cart();
                $settings = Settings::get_settings();
                $cart_redirect = $settings[0]->cart_redirect;

                if ($bundles && is_array($bundles)) {

                    $use_custom_variations = $bundles[0]->use_custom_variations; ?>

                    <div class="wbdl_widget" product_id="<?php echo esc_attr($product_id); ?>" <?php if ($cart_redirect) { ?> cart_redirect="<?php echo esc_attr($cart_redirect);
                                                                                                                                            } ?>" cellspacing="0">
                        <style>
                            table.variations {
                                display: none !important;
                            }

                            <?php
                            if ($settings[0]->qty_selector == 'off') {
                            ?>.woocommerce .product button.single_add_to_cart_button {
                                height: 70px !important;
                                width: 100% !important;
                                margin-left: 0 !important;
                            }

                            .woocommerce .product .quantity {
                                display: none !important;
                            }

                            <?php
                            }
                            ?>.custom-bundle-three {
                                border-color: <?php esc_html_e($settings[0]->border_color); ?> !important;
                                background: <?php esc_html_e($settings[0]->background_color); ?> !important
                            }

                            .custom-bundle-three.active {
                                border-color: <?php esc_html_e($settings[0]->border_color_active); ?> !important;
                                background: <?php esc_html_e($settings[0]->background_color_active); ?> !important;
                            }

                            .custom-bundle-three .b_title {
                                color: <?php esc_html_e($settings[0]->title_color); ?> !important;
                            }

                            .custom-bundle-three.active .bundle-message-blink-three,
                            .custom-bundle-three.active .bundle-message-not-blink-three {
                                color: <?php esc_html_e($settings[0]->message1_color); ?> !important
                            }

                            .custom-bundle-three .discount-rule-three,
                            .custom-bundle-three.active .discount-rule-three {
                                color: <?php esc_html_e($settings[0]->message2_color); ?> !important
                            }

                            .custom-bundle-three .bundle-price-three {
                                color: <?php esc_html_e($settings[0]->sale_price_color); ?> !important
                            }

                            .custom-bundle-three .bundle-cprice-three {
                                color: <?php esc_html_e($settings[0]->regular_price_color); ?> !important
                            }

                            .custom-bundle-three .radio-button input[type=radio]:checked:before {
                                background: <?php esc_html_e($settings[0]->border_color_active); ?> !important
                            }
                        </style>

                        <tbody>
                            <input type="hidden" name="wbdl_nonce" value="<?php echo wp_create_nonce('bundler'); ?>">
                            <input type="hidden" class="productType" name="wbdl_product_type" value="<?php esc_attr_e($product->get_type()); ?>">
                            <input type="hidden" class="Btitle" name="bundle_title">
                            <input type="hidden" class="productID" name="product_id" value="<?php esc_attr_e($product_id); ?>">
                            <input type="hidden" class="Bprice" name="bundle_hidden_price">
                            <input type="hidden" class="Pimage" name="bundle_hidden_image" value="">
                            <input type="hidden" class="Cvar" name="use_custom_variations" value="<?php esc_attr_e($use_custom_variations); ?>">

                            <?php if ($settings[0]->title_show == 'on') {  ?> <div class="custom-title"><?php esc_html_e($settings[0]->bundles_title); ?></div> <?php } ?>

                            <?php include WBDL_PLUGIN_DIR . 'App/Views/templates/classic.php'; ?>
                        </tbody>
                    </div>
<?php
                }
            }
        }
    }
}
