jQuery(document).ready(function ($) {
  const alert_counter = { counts: 1 };
  addGoProLink();

  /**
   * add go pro link to submenu section
   */
  function addGoProLink() {
    var goProLink = $(
      '#toplevel_page_bundler ul.wp-submenu a[href="admin.php?page=bundler/upgrade"]'
    );

    if (goProLink.length) {
      goProLink
        .parent()
        .html(
          '<a target=”_blank” href="https://wcbundler.com/pricing"><span class="button button-primary bundler-upgrade-button">Go Pro <span class="dashicons dashicons-external"></span></span></a>'
        );
    }
  }

  /**
   * alert notification
   * @param message
   * @param type
   * @param alert_counter
   */
  function notify(message, type = "success", alert_counter = null) {
    switch (type) {
      case "error":
        var class_name = "wbdl-alert-error";
        break;
      case "warning":
        var class_name = "wbdl-alert-warning";
        break;
      default:
      case "success":
        var class_name = "wbdl-alert-success";
        break;
    }

    let div_id = "wbdl-notify-msg-" + alert_counter.counts;
    let html =
      '<div style="display:none;" class="wbdl-alert ' +
      class_name +
      '" id="' +
      div_id +
      '">' +
      message +
      "</div>";
    let notify_holder = jQuery("#notify-msg-holder");
    notify_holder.append(html);
    let message_div = jQuery("#" + div_id);
    var notify_count = alert_counter.counts;
    alert_counter.counts = parseInt(notify_count) + parseInt(1);
    message_div.fadeIn(500);
    setTimeout(function () {
      message_div.fadeOut(500);
      message_div.remove();
    }, 5000);
  }

  /**
   * offer form validation functions
   * @return bool
   */
  function validateOfferForm() {
    // 1) check the offer details:
    let offerTitleIsValid = validateOfferTitle();
    let offerTypeIsValid = validateOfferType();
    let productIDIsValid = validateProductID();
    if (!offerTitleIsValid || !offerTypeIsValid || !productIDIsValid) {
      alert("Some required fields are missing.");
      jQuery("input[name='offer_title']").each(function () {
        jQuery(this).keyup(function () {
          validateOfferTitle();
        });
      });
      jQuery("select[name='discount_type']").on("change", function () {
        validateOfferType();
      });
      jQuery("#product-selector").on("change", function () {
        // Get the selected product ID
        validateProductID();
      });
      return false;
    }

    // 2) Check the bundles table
    var isFormEmpty = true;
    jQuery(document)
      .find(".wbdl")
      .find(".offers_list")
      .find("input")
      .each(function () {
        var element = jQuery(this);
        if (
          element.val() != "" &&
          element.attr("name") != "wbdl_product_id" &&
          element.attr("name") != "preselected_count[]" &&
          element.attr("name") != "preselected_offer[]"
        ) {
          isFormEmpty = false;
          return false;
        }
      });

    // 3) Check the bundles

    if (!isFormEmpty) {
      let bundleTitleIsValid = validateBundleTitle();
      let productsQtyIsValid = validateProductsNumber();
      let salePriceIsValid = validateSalePrice();
      if (!bundleTitleIsValid || !productsQtyIsValid || !salePriceIsValid) {
        alert(
          "Some required fields are missing in the discount rules section."
        );
        jQuery(".wbdl_bundle_title").each(function () {
          jQuery(this).keyup(function () {
            validateBundleTitle();
          });
        });
        jQuery(".wbdl_product_qty").each(function () {
          jQuery(this).change(function () {
            validateProductsNumber();
          });
        });
        jQuery(".wbdl_sale_price").each(function () {
          jQuery(this).keyup(function () {
            validateSalePrice();
          });
        });
        return false;
      } else {
        if (!validateRegularPriceIsBigger()) {
          e.preventDefault();
          alert("Bundler : Regular price has to be greater than sale price.");
          return false;
        } else {
          // Everything is ok!
          // If an offer is preselected, add its ID to the hidden field
          var preselectedOffer = jQuery('input[name="preselected_offer[]"]');
          for (var i = 0; i < preselectedOffer.length; i++) {
            if (jQuery(preselectedOffer[i]).is(":checked")) {
              jQuery('input[name="preselected_offer_id"]').attr("value", i);
            }
          }
          return true;
        }
      }
    }

    return true;
  }

  /**
   * Validate offer title
   * @return bool
   */
  function validateOfferTitle() {
    let offerTitleIsValid = true;
    jQuery("input[name='offer_title']").each(function () {
      let offerTitleValue = jQuery(this).val();
      if (offerTitleValue.length == "") {
        jQuery(this).addClass("error");
        offerTitleIsValid = false;
        return false;
      } else {
        jQuery(this).removeClass("error");
      }
    });
    return offerTitleIsValid;
  }

  /**
   * Validate Offer type
   * @return bool
   */
  function validateOfferType() {
    let offerTypeIsValid = true;
    jQuery(".wbdl")
      .find("select[name='discount_type']")
      .each(function () {
        let offerTypeValue = jQuery(this).val();
        if (offerTypeValue == "not_selected") {
          jQuery(this).addClass("error");
          offerTypeIsValid = false;
          return false;
        } else {
          jQuery(this).removeClass("error");
        }
      });
    return offerTypeIsValid;
  }

  /**
   * Validate Offer type
   * @return bool
   */
  function validateProductID() {
    let productIDIsValid = true;
    jQuery(".wbdl")
      .find("input[name='product_id']")
      .each(function () {
        let productID = jQuery(this).val();
        if (!productID || productID == "") {
          jQuery(".wbdl").find(".select2-selection").addClass("error");
          productIDIsValid = false;
          return false;
        } else {
          jQuery(".wbdl").find(".select2-selection").removeClass("error");
        }
      });
    return productIDIsValid;
  }

  /**
   * Validate Bundle Title
   *
   * @return bool
   */
  function validateBundleTitle() {
    let bundleTitleIsValid = true;
    jQuery(".wbdl_bundle_title").each(function () {
      let bundleTitleValue = jQuery(this).val();
      if (bundleTitleValue.length == "") {
        jQuery(this).addClass("error");
        bundleTitleIsValid = false;
        return false;
      } else {
        jQuery(this).removeClass("error");
      }
    });
    return bundleTitleIsValid;
  }

  /**
   * Validate Products Qty
   * @return bool
   */
  function validateProductsNumber() {
    let productQtyIsValid = true;
    jQuery(".wbdl_product_qty").each(function () {
      let productsNumberValue = jQuery(this).val();
      if (productsNumberValue.length == "") {
        jQuery(this).addClass("error");
        productQtyIsValid = false;
        return false;
      } else {
        jQuery(this).removeClass("error");
      }
    });
    return productQtyIsValid;
  }

  /**
   * Validate Bundle Price
   *  @return bool
   */
  function validateSalePrice() {
    let salePriceIsValid = true;
    jQuery(".wbdl_sale_price").each(function () {
      let salePriceValue = jQuery(this).val();
      if (salePriceValue.length == 0) {
        salePriceIsValid = false;
        jQuery(this).addClass("error");
        return false;
      } else {
        jQuery(this).removeClass("error");
      }
    });
    return salePriceIsValid;
  }

  /**
   * Validate Bundle Regular Price
   * @return bool
   */
  function validateRegularPriceIsBigger() {
    var regularPriceInputs = jQuery(".wbdl_regular_price");
    var salePriceInputs = jQuery(".wbdl_sale_price");

    if (regularPriceInputs.length && salePriceInputs.length) {
      for (var i = 0; i < regularPriceInputs.length; i++) {
        if (
          parseFloat(jQuery(regularPriceInputs[i]).val()) <=
          parseFloat(jQuery(salePriceInputs[i]).val())
        ) {
          return false;
        }
      }
    } else if (regularPriceInputs.length && !salePriceInputs.length) return true;

    return true;
  }

  /**
   * Add new offer
   * @param mixed data
   * @return void
   */
  function addNewOffer(data) {
    $.ajax({
      type: "POST",
      url: admin_script_vars.ajax_url,
      data: {
        action: "wbdl_new_offer",
        data: data,
      },
      dataType: "json",
      success: function (response) {
        $(".wbdl").find(".woo_discount_loader").css({
          display: "none",
        });

        if (response == "success") {
          notify("Offer created successfully!", "success", 1);
          window.location = admin_script_vars.offers_page_url;
        } else if (response == "license error") {
          notify(
            "You can create offers for simple products only with Bundler Lite!",
            "error",
            1
          );
        } else {
          notify("Error creating the offer!!", "error", 1);
        }
      },
      error: function (xhr, status, error) {
        // Show an error message
      },
    });
  }

  /**
   * Update offer
   * @param mixed data
   * @return void
   */
  function updateOffer(data) {
    $.ajax({
      type: "POST",
      url: admin_script_vars.ajax_url,
      data: {
        action: "wbdl_update_offer",
        data: data,
      },
      dataType: "json",
      success: function (response) {
        $(".wbdl").find(".woo_discount_loader").css({
          display: "none",
        });
        if (response == "success") {
          notify("Offer created successfully!", "success", 1);
        } else if (response == "license error") {
          notify(
            "You can create offers for simple products only with Bundler Lite!",
            "error",
            1
          );
        } else {
          console.log(response);
          notify("Error creating the offer!!", "error", 1);
        }
      },
      error: function (xhr, status, error) {
        // Show an error message
      },
    });
  }

  /**
   * Remove offer
   * @param mixed offerId
   * @return void
   */
  function removeOffer(offerId) {
    $.ajax({
      type: "POST",
      url: admin_script_vars.ajax_url,
      data: {
        action: "wbdl_delete_offer",
        offer_id: offerId,
      },
      dataType: "json",
      success: function (response) {
        $(".wbdl").find(".woo_discount_loader").css({
          display: "none",
        });
        if (response == "success") {
          notify("Offer deleted successfully!", "success", 1);
          $("#offer-" + offerId).remove();
        } else {
          notify("Error deleting the offer!!", "error", 1);
        }
      },
      error: function (xhr, status, error) {
        // Show an error message
      },
    });
  }

  /**
   * Enable/disable offer
   * @param mixed offerId
   * @param mixed status
   * @return void
   */
  function updateOfferStatus(offerId, status) {
    // Send an AJAX request
    var enabled = status == "on" ? "enabled" : "disabled";
    $.ajax({
      type: "POST",
      url: admin_script_vars.ajax_url,
      data: {
        action: "wbdl_change_offer_status",
        offer_id: offerId,
        status: status,
      },
      dataType: "json",
      success: function (response) {
        $(".wbdl").find(".woo_discount_loader").css({
          display: "none",
        });
        if (response == "success") {
          notify(
            "Offer " + enabled + " successfully!",
            "success",
            alert_counter
          );
        } else {
          notify("Error changing the offer status!!", "error", alert_counter);
        }
      },
      error: function (xhr, status, error) {
        // Show an error message
      },
    });
  }

  /* Event listeners */

  // Allow one offer only to be selected on the bundle creation form
  $(document).on("change", 'input[name="preselected_offer[]"]', function () {
    if (this.checked) {
      $('input[name="preselected_offer[]"]').not(this).prop("checked", false);
    }
  });

  // Show/Hide custom variations fields in the offer form
  $(document).on("click", 'input[name="use_custom_variations"]', function () {
    if (this.checked) {
      $(document).find(".wbdl_custom_options").show();
      $(document).find(".wbdl_custom_options").show();
    } else {
      $(document).find(".wbdl_custom_options").hide();
      $(document).find(".wbdl_custom_options").hide();
    }
  });

  // Add custom messages in the offer form
  $(document).on("click", 'input[class="add_custom_messages"]', function () {
    var hiddenInput = $(this)
      .closest(".title-input-offer")
      .find(".hidden_add_messages");

    if (this.checked) {
      hiddenInput.val("on");
      $(this).closest(".content-sentence").find(".custom-messages").show();
    } else {
      hiddenInput.val("off");
      $(this).closest(".content-sentence").find(".custom-messages").hide();
    }
  });

  /* disable scroll on number inputs when focused */
  $(document).on("focus", 'input[type=number][class^="wbdl"]', function (e) {
    $(this).on("wheel.disableScroll", function (e) {
      e.preventDefault();
    });
  });
  $(document).on("blur", 'input[type=number][class^="wbdl"]', function (e) {
    $(this).off("wheel.disableScroll");
  });

  // Info popup
  $(".info-popup-message").each(function (index) {
    $(".info-popup-message").hide();
  });
  $(".info-popup").each(function (index) {
    $(this)
      .find(".icon-popup")
      .mouseover(function (event) {
        if (!event.target.classList.contains("info-popup-message")) {
          $(this).parent().find(".info-popup-message").fadeIn("fast");
        }
      });
    $(this)
      .find(".icon-popup")
      .mouseout(function (event) {
        if (!event.target.classList.contains("info-popup-message")) {
          $(this).parent().find(".info-popup-message").fadeOut("fast");
        }
      });
  });

  /* Product selector AJAX */

  // Initialize selectWoo on the select input field
  $("#product-selector").selectWoo({
    width: "102%",
    //placeholder: 'Search for a product',
    minimumInputLength: 1, // Minimum characters required before making an AJAX request
    ajax: {
      url: admin_script_vars.ajax_url, // Replace with your AJAX handler URL
      type: "POST",
      dataType: "json",
      delay: 250,
      data: function (params) {
        return {
          query: params.term,
          action: "wbdl_search_products",
          //method: $(this).data('list') || 'products',
          wbdl_nonce: $("input[name=wbdl_product_search_nonce]").val() || "",
          //taxonomy: $(this).data('taxonomy') || '',
          //selected: $(this).val()
        };
      },
      error: function (xhr, textStatus, errorThrown) {
        console.log("AJAX Error:", errorThrown);
      },
      processResults: function (response) {
        return {
          results: response.data || [],
        };
      },
    },
  });
  $("#product-selector").on("change", function () {
    // Get the selected product ID
    $(".wbdl_product_id").val($(this).val());
  });

  /* New Offer AJAX */

  $("#wbdl-new-offer").on("submit", function (e) {
    e.preventDefault();
    let isFormValid = validateOfferForm();
    if (isFormValid) {
      $(".wbdl").find(".woo_discount_loader").css({
        display: "block",
      });

      var form = $(this);
      var data = form.serialize();
      addNewOffer(data);
    }
  });

  /* Edit Offer AJAX */
  $("#wbdl-edit-offer").on("submit", function (e) {
    e.preventDefault();
    let isFormValid = validateOfferForm();
    if (isFormValid) {
      $(".wbdl").find(".woo_discount_loader").css({
        display: "block",
      });

      var form = $(this);
      var data = form.serialize();
      updateOffer(data);
    }
  });

  /* Remove Offer AJAX */
  $(".wbdl-delete-offer").on("click", function (e) {
    if (confirm("Are you sure you want to delete this offer?")) {
      var offerId = $(this)
        .closest(".wbdl-listing-offer-tr")
        .attr("id")
        .replace("offer-", "");

      $(".wbdl").find(".woo_discount_loader").css({
        display: "block",
      });
      removeOffer(offerId);
    } else {
      // Do nothing!
    }
  });

  /* Enable/Disable Offer AJAX */
  $(".wbdl_manage_status").on("change", function (e) {
    var offerId = $(this)
      .closest(".wbdl-listing-offer-tr")
      .attr("id")
      .replace("offer-", "");
    var status = $(this).is(":checked") ? "on" : "off";

    $(".wbdl").find(".woo_discount_loader").css({
      display: "block",
    });
    updateOfferStatus(offerId, status);
  });
});
