<?php
/* 
 * Plugin Name:  Bundler Lite
 * Plugin URI:   https://wcbundler.com/
 * Description:  Create bundle offers that convert. Bundler Core package.
 * Version:      2.1.5.7
 * Author:       WooBundles
 * Author URI:   https://wcbundler.com
 * License:      GPLv3
 * License URI:  http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:  woobundles
 * Domain Path:  /languages
 * 
 * Woobundles is a free software.
 * You can redistribute it and/or modify it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * WooBundles is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with WooBundles. If not, see <http://www.gnu.org/licenses/>.
*/


if (!defined('ABSPATH'))  exit; // Exit if accessed directly

if (!function_exists('is_plugin_active')) {
    require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

if (!defined('WBDL_VERSION')) {
    define('WBDL_VERSION', '2.1.5.7');
}

if (!defined('WBDL_PLUGIN_FILE')) {
    define('WBDL_PLUGIN_FILE', __FILE__);
}

if (!defined('WBDL_PLUGIN_BASENAME')) {
    define('WBDL_PLUGIN_BASENAME', plugin_basename(__FILE__));
}

require_once plugin_dir_path(__FILE__) . '/includes/define.php';

/**
 *  Don't allow multiple versions to be active.
 * */
if (function_exists('wbdl')) {

    if (!function_exists('wbdl_pro_just_activated')) {
        /**
         * When we activate a Pro version, we need to do additional operations:
         * 1) deactivate a Lite version;
         * 2) register option which help to run all activation process for Pro version (custom tables creation, etc.).
         *
         * @since 1.0.0
         */
        function wbdl_pro_just_activated()
        {
            set_transient('wbdl_pro_just_activated', true);
            wbdl_lite_deactivate();
            add_option('wbdl_install', 1);
        }
    }
    add_action('activate_bundler-pro/bundler.php', 'wbdl_pro_just_activated');

    if (!function_exists('wbdl_lite_deactivate')) {
        /**
         * Deactivate Lite if Bundler already activated.
         *
         * @since 1.0.0
         */
        function wbdl_lite_deactivate()
        {

            $plugin = 'bundler/bundler.php';

            deactivate_plugins($plugin);

            //do_action( 'wbdl_plugin_deactivated', $plugin );
        }
    }
    add_action('admin_init', 'wbdl_lite_deactivate');

    if (!function_exists('wbdl_lite_just_activated')) {
        /**
         * Store temporarily that the Lite version of the plugin was activated.
         * This is needed because WP does a redirect after activation and
         * we need to preserve this state to know whether user activated Lite or not.
         *
         * @since 1.0.0
         */
        function wbdl_lite_just_activated()
        {

            if (get_transient('wbdl_pro_just_activated')) {
                wbdl_lite_deactivate();
                set_transient('wbdl_lite_just_deactivated', true);
            } else {
                set_transient('wbdl_lite_just_activated', true);
            }
        }
    }
    add_action('activate_bundler/bundler.php', 'wbdl_lite_just_activated');

    // Do not process the plugin code further.
    return;
}


/**
 * Store temporarily that Bundler has been activated for the first time.
 * 
 * @since 1.2.8
 * */
if (!function_exists('wbdl_activation')) {
    function wbdl_activation()
    {
        set_transient('wbdl_first_time_activated', true);
    }
    register_activation_hook(__FILE__, 'wbdl_activation');
}


// Redirect to the offers page after plugin's activation.
if (!function_exists('wbdl_plugin_activated')) {
    function wbdl_plugin_activated($plugin)
    {
        if ($plugin == plugin_basename(__FILE__)) {
            exit(wp_redirect(admin_url('admin.php?page=bundler')));
        }
    }
    add_action('activated_plugin', 'wbdl_plugin_activated');
}

/**
 * Display admin notices
 * */

if (!function_exists('wbdl_lite_notice')) {
    /**
     * Display the notice after deactivation when Pro is still active
     * and user wanted to activate the Lite version of the plugin.
     *
     * @since 1.0.0
     */
    function wbdl_lite_notice()
    {

        if (get_transient('wbdl_lite_just_deactivated')) {
            // Currently tried to activate Lite with Pro still active, so display the message.
            printf(
                '<div class="notice notice-warning is-dismissible">
                    <p>%1$s</p>
                    <p>%2$s</p>
                </div>',
                esc_html__('Heads up!', 'woobundles'),
                esc_html__('Your site already has Bundler Pro activated. If you want to switch to Bundler Lite, please first go to Plugins → Installed Plugins and deactivate Bundler Pro. Then, you can activate Bundler Lite.', 'woobundles')
            );

            if (isset($_GET['activate'])) { // phpcs:ignore WordPress.Security.NonceVerification.Recommended
                unset($_GET['activate']); // phpcs:ignore WordPress.Security.NonceVerification.Recommended
            }

            delete_transient('wbdl_lite_just_deactivated');
        }

        if (get_transient('wbdl_first_time_activated')) {
            printf(
                '<div class="updated notice is-dismissible">
                    <p>Bundler is active now!</p>
                    <p>To start setting up bundle offers and discounts, go to your product admin page and <a href="https://youtu.be/JlNotPMqPgw" target="_blank">follow this video tutorial.</a></p>
                </div>'
            );
            delete_transient('wbdl_first_time_activated');
        }
    }
    add_action('admin_notices', 'wbdl_lite_notice');
}



/**
 *  We require PHP version 5.6+ for the whole plugin to work.
 */

if (version_compare(phpversion(), WBDL_REQUIRED_PHP_VERSION, '<')) {

    if (!function_exists('wbdl_php56_notice')) {

        /**
         * Display the notice about incompatible PHP version after deactivation.
         *
         * @since 1.0.0
         */
        function wbdl_php56_notice()
        {

?>
            <div class="notice notice-error">
                <p>
                    <?php
                    printf(
                        wp_kses(
                            __('The WooBundles plugin is disabled on your site until you fix the issue: Your site is running an <strong>insecure version</strong> of PHP that is no longer supported. Please contact your web hosting provider to update your PHP version.', 'woobundles')
                        )
                    );
                    ?>
                </p>
            </div>

            <?php
            // In case this is on plugin activation.
            // phpcs:disable WordPress.Security.NonceVerification.Recommended
            if (isset($_GET['activate'])) {
                unset($_GET['activate']);
            }
            // phpcs:enable WordPress.Security.NonceVerification.Recommended
        }
    }

    add_action('admin_notices', 'wbdl_php56_notice');

    // Do not process the plugin code further.
    return;
}


/**
 * We require WC version 3.3+ for the whole plugin to work.
 */

add_action('plugins_loaded', function () {
    if (class_exists('woocommerce')) {

        if (version_compare(WC_VERSION, WBDL_WC_REQUIRED_VERSION, '<')) {

            if (!function_exists('wbdl_woocommerce_version_admin_notice')) {

                /**
                 * Message if WooCommerce version is < 3.3.
                 */

                function wbdl_woocommerce_version_admin_notice()
                {
            ?>
                    <div class="error">
                        <p><?php esc_html_e('The WooBundles plugin requires WooCommerce version above 3.3 to work.', 'woobundles'); ?></p>
                    </div>
                <?php
                    // In case this is on plugin activation.
                    // phpcs:disable WordPress.Security.NonceVerification.Recommended
                    if (isset($_GET['activate'])) {
                        unset($_GET['activate']);
                    }
                }
            }
            add_action('admin_notices', 'wbdl_woocommerce_version_admin_notice');
            // Do not process the plugin code further.
            return;
        }
    } else {

        if (!function_exists('wbdl_install_woocommerce_admin_notice')) {

            /**
             * Message if WooCommerce plugin is not installed.
             */

            function wbdl_install_woocommerce_admin_notice()
            {
                ?>
                <div class="error">
                    <p><?php esc_html_e('The WooBundles plugin cannot run without WooCommerce active. Please install and activate WooCommerce plugin.', 'woobundles'); ?></p>
                </div>
<?php
                // In case this is on plugin activation.
                // phpcs:disable WordPress.Security.NonceVerification.Recommended
                if (isset($_GET['activate'])) {
                    unset($_GET['activate']);
                }
            }
        }
        add_action('admin_notices', 'wbdl_install_woocommerce_admin_notice');
        // Do not process the plugin code further.
        return;
    }
}, 1);

require_once dirname(__FILE__) . '/App/Bundler.php';

wbdl();
